@@ -100,6 +100,7 @@ def _get_arch():
 @click.option("-cR", "--additional_config_raw", help="like ODOO_DEMO=1;RUN_PROXY=0")
 @click.option("--images-url", help="default: https://github.com/marcwimmer/odoo")
 @click.option("-I", "--no-update-images", is_flag=True)
+@click.option("-A", "--no-auto-repo", is_flag=True)
 @pass_config
 @click.pass_context
 def do_reload(
@@ -115,6 +116,7 @@ def do_reload(
     additional_config_raw,
     images_url,
     no_update_images,
+    no_auto_repo,
 ):
     from .myconfigparser import MyConfigParser
 
@@ -161,6 +163,7 @@ def do_reload(
                 demo = True
 
         internal_reload(
+            ctx,
             config,
             db,
             demo,
@@ -169,17 +172,20 @@ def do_reload(
             proxy_port,
             mailclient_gui_port,
             additional_config,
+            apply_auto_repo=not no_auto_repo,
         )
 
     finally:
         if additional_config_file and additional_config_file.exists():
             additional_config_file.unlink()
 
+
 def get_arch():
     return platform.uname().machine  # aarch64
 
 
 def internal_reload(
+    ctx,
     config,
     db,
     demo,
@@ -189,6 +195,7 @@ def internal_reload(
     proxy_port,
     mailclient_gui_port,
     additional_config=None,
+    apply_auto_repo=True,
 ):
     ensure_project_name(config)
     defaults = {
@@ -224,6 +231,9 @@ def internal_reload(
 
         click.secho("Additional config: {defaults}")
 
+    if apply_auto_repo:
+        _apply_autorepo(ctx=ctx, config=config)
+
     # assuming we are in the odoo directory
     _do_compose(**defaults)
 
@@ -301,7 +311,9 @@ def _download_images(config, images_url):
     #     cwd=config.dirs["images"],
     # )
     current_branch = subprocess.check_output(
-        ["git", "rev-parse", "--abbrev-ref", "HEAD"], encoding="utf8", cwd=config.dirs["images"]
+        ["git", "rev-parse", "--abbrev-ref", "HEAD"],
+        encoding="utf8",
+        cwd=config.dirs["images"],
     ).strip()
     if config.ODOO_IMAGES_BRANCH and config.ODOO_IMAGES_BRANCH != current_branch:
         subprocess.check_call(["git", "checkout", config.ODOO_IMAGES_BRANCH])
@@ -926,4 +938,17 @@ def _use_file(config, path):
     return res
 
 
+def _apply_autorepo(ctx, config):
+    from .odoo_config import MANIFEST_CLASS, customs_dir
+
+    manifest = MANIFEST_CLASS()
+    if not manifest.get("auto_repo", False):
+        return
+
+    from .lib_src import _turn_into_odoosh, _fetch_modules
+
+    _turn_into_odoosh(ctx, customs_dir())
+    _fetch_modules(config)
+
+
 Commands.register(do_reload, "reload")
