@@ -273,4 +273,39 @@ def clear_cache(config):
     ModulesCache._clear_cache()
 
 
+@src.command
+@click.option("-f", "--fix-not-in-manifest", is_flag=True)
+@pass_config
+def show_installed_modules(config, fix_not_in_manifest):
+    from .module_tools import DBModules, Module
+    from .odoo_config import customs_dir
+    path = customs_dir()
+    collected = []
+    not_in_manifest = []
+    manifest = MANIFEST()
+    setinstall = manifest.get('install', [])
+
+    for module in sorted(DBModules.get_all_installed_modules()):
+        try:
+            mod = Module.get_by_name(module)
+            click.secho(f"{module}: {mod.path}", fg='green')
+            if not [x for x in setinstall if x == module]:
+                not_in_manifest.append(module)
+        except KeyError:
+            collected.append(module)
+
+    for module in not_in_manifest:
+        if fix_not_in_manifest:
+            setinstall += [module]
+            click.secho(f"Added to manifest: {module}", fg='green')
+        else:
+            click.secho(f"Not in MANIFEST: {module}", fg='yellow')
+    for module in collected:
+        click.secho(f"Not in filesystem: {module}", fg='red')
+
+    if fix_not_in_manifest:
+        manifest['install'] = setinstall
+        manifest.rewrite()
+
+
 Commands.register(clear_cache)
